@@ -82,6 +82,14 @@
         <translation>El campo nombre no puede estar vacío</translation>
     </message>
 </context>
+<context>
+    <name>ConceptsChart</name>
+    <message>
+        <location filename="../src/conceptschart.cpp" line="154"/>
+        <source>No item</source>
+        <translation>Sin concepto</translation>
+    </message>
+</context>
 <context>
     <name>ConceptsDialog</name>
     <message>
@@ -116,76 +124,119 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../src/controller.cpp" line="74"/>
+        <location filename="../src/controller.cpp" line="77"/>
         <source>Already at current month</source>
         <translation>Ya está en el mes actual</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="125"/>
+        <location filename="../src/controller.cpp" line="128"/>
         <source>Error deleting expense</source>
         <translation>Error eliminando gasto</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="136"/>
+        <location filename="../src/controller.cpp" line="139"/>
         <source>Error updating expense</source>
         <translation>Error actualizando gasto</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="203"/>
+        <location filename="../src/controller.cpp" line="206"/>
         <source>Error creating concept</source>
         <translation>Error creando concepto</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="206"/>
+        <location filename="../src/controller.cpp" line="209"/>
         <source>Concept already exists</source>
         <translation>El concepto ya existe</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="213"/>
+        <location filename="../src/controller.cpp" line="216"/>
         <source>When deleting a concept, all the expenses associated to it will be assigned an empty concept instead.
 Are you sure you want to delete the concept?</source>
         <translation>Al eliminar un concepto, a todos los gastos asociados a ese concepto se les asignará un concepto vacío en su lugar.
 ¿Está seguro de que desea eliminar el concepto?</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="222"/>
+        <location filename="../src/controller.cpp" line="225"/>
         <source>Error deleting concept</source>
         <translation>Error eliminando concepto</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="233"/>
+        <location filename="../src/controller.cpp" line="236"/>
         <source>Error updating concept</source>
         <translation>Error actualizando concepto</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="279"/>
+        <location filename="../src/controller.cpp" line="282"/>
         <source>Current month fits in the scheduled expense description.
 Do you want the expense to be created in it?</source>
         <translation>El mes actual cumple la descripción para el gasto planificado.
 ¿Desea que el gasto sea creado en él?</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="289"/>
+        <location filename="../src/controller.cpp" line="292"/>
         <source>Error creating scheduled expense</source>
         <translation>Error creando el gasto planificado</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="300"/>
+        <location filename="../src/controller.cpp" line="303"/>
         <source>Error deleting scheduled expense</source>
         <translation>Error eliminando gasto planificado</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="320"/>
+        <location filename="../src/controller.cpp" line="323"/>
         <source>Current month fits in the scheduled expense description after the modification.
 Do you want the expense to be created in it?</source>
         <translation>El mes actual cumple la descripción para el gasto planificado tras la modificación.
 ¿Desea que el gasto sea creado en él?</translation>
     </message>
     <message>
-        <location filename="../src/controller.cpp" line="330"/>
+        <location filename="../src/controller.cpp" line="333"/>
         <source>Error updating scheduled expense</source>
         <translation>Error actualizando gasto planificado</translation>
     </message>
+    <message>
+        <location filename="../src/controller.cpp" line="353"/>
+        <source>Error loading data interval</source>
+        <translation>Error cargando datos de intervalo</translation>
+    </message>
+    <message>
+        <location filename="../src/controller.cpp" line="363"/>
+        <source>Error loading interval data</source>
+        <translation>Error cargando datos de período</translation>
+    </message>
+</context>
+<context>
+    <name>DateChooserDialog</name>
+    <message>
+        <location filename="../src/datechooserdialog.cpp" line="29"/>
+        <source>Choose a date</source>
+        <translation>Seleccione una fecha</translation>
+    </message>
+    <message>
+        <location filename="../src/datechooserdialog.cpp" line="80"/>
+        <source>Done</source>
+        <translation>Hecho</translation>
+    </message>
+    <message>
+        <location filename="../src/datechooserdialog.cpp" line="101"/>
+        <source>Choose a month</source>
+        <translation>Seleccione un mes</translation>
+    </message>
+    <message>
+        <location filename="../src/datechooserdialog.cpp" line="110"/>
+        <source>Choose a year</source>
+        <translation>Seleccione un año</translation>
+    </message>
+    <message>
+        <location filename="../src/datechooserdialog.cpp" line="115"/>
+        <source>Minimum date is %1 %2</source>
+        <translation>La fecha mínima es %1 de %2</translation>
+    </message>
+    <message>
+        <location filename="../src/datechooserdialog.cpp" line="123"/>
+        <source>Maximum date is %1 %2</source>
+        <translation>La fecha máxima es %1 de %2</translation>
+    </message>
 </context>
 <context>
     <name>ExpenseDetailsDialog</name>
@@ -293,16 +344,54 @@ Do you want the expense to be created in it?</source>
         <translation>Planificados</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="105"/>
+        <location filename="../src/mainwindow.cpp" line="55"/>
+        <source>Summary</source>
+        <translation>Resumen</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cpp" line="106"/>
         <source>accumulated view</source>
         <translation>vista acumulada</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cpp" line="107"/>
+        <location filename="../src/mainwindow.cpp" line="108"/>
         <source>daily view</source>
         <translation>vista diaria</translation>
     </message>
 </context>
+<context>
+    <name>PeriodWindow</name>
+    <message>
+        <location filename="../src/periodwindow.cpp" line="35"/>
+        <source>Months from</source>
+        <translation>Meses desde</translation>
+    </message>
+    <message>
+        <location filename="../src/periodwindow.cpp" line="43"/>
+        <source>to</source>
+        <translation>hasta</translation>
+    </message>
+    <message>
+        <location filename="../src/periodwindow.cpp" line="51"/>
+        <source>Update</source>
+        <translation>Actualizar</translation>
+    </message>
+    <message>
+        <location filename="../src/periodwindow.cpp" line="63"/>
+        <source>Choose a period start date</source>
+        <translation>Seleccione una fecha de inicio para el período</translation>
+    </message>
+    <message>
+        <location filename="../src/periodwindow.cpp" line="68"/>
+        <source>Choose a period finish date</source>
+        <translation>Seleccione una fecha de fin para el período</translation>
+    </message>
+    <message>
+        <location filename="../src/periodwindow.cpp" line="74"/>
+        <source>Start date must be prior to end date</source>
+        <translation>La fecha de inicio debe ser anterior a la fecha de fin</translation>
+    </message>
+</context>
 <context>
     <name>ScheduledDetailsDialog</name>
     <message>
@@ -396,4 +485,75 @@ Do you want the expense to be created in it?</source>
         <translation>Nuevo</translation>
     </message>
 </context>
+<context>
+    <name>SummaryWindow</name>
+    <message>
+        <location filename="../src/summarywindow.cpp" line="17"/>
+        <source>Month Summary</source>
+        <translation>Resumen de meses</translation>
+    </message>
+    <message>
+        <location filename="../src/summarywindow.cpp" line="20"/>
+        <source>Statistics</source>
+        <translation>Estadísticas</translation>
+    </message>
+    <message>
+        <location filename="../src/summarywindow.cpp" line="22"/>
+        <source>Items</source>
+        <translation>Conceptos</translation>
+    </message>
+    <message>
+        <location filename="../src/summarywindow.cpp" line="42"/>
+        <source>Period totals</source>
+        <translation>Totales del período</translation>
+    </message>
+    <message>
+        <location filename="../src/summarywindow.cpp" line="43"/>
+        <source>Budget</source>
+        <translation>Presupuesto</translation>
+    </message>
+    <message>
+        <location filename="../src/summarywindow.cpp" line="46"/>
+        <source>Expenses</source>
+        <translation>Gastos</translation>
+    </message>
+    <message>
+        <location filename="../src/summarywindow.cpp" line="49"/>
+        <source>Saved</source>
+        <translation>Ahorro</translation>
+    </message>
+    <message>
+        <location filename="../src/summarywindow.cpp" line="53"/>
+        <source>Period expenses</source>
+        <translation>Gastos del período</translation>
+    </message>
+    <message>
+        <location filename="../src/summarywindow.cpp" line="54"/>
+        <location filename="../src/summarywindow.cpp" line="65"/>
+        <source>Minimum</source>
+        <translation>Mínimo</translation>
+    </message>
+    <message>
+        <location filename="../src/summarywindow.cpp" line="57"/>
+        <location filename="../src/summarywindow.cpp" line="68"/>
+        <source>Maximum</source>
+        <translation>Máximo</translation>
+    </message>
+    <message>
+        <location filename="../src/summarywindow.cpp" line="60"/>
+        <location filename="../src/summarywindow.cpp" line="71"/>
+        <source>Average</source>
+        <translation>Media</translation>
+    </message>
+    <message>
+        <location filename="../src/summarywindow.cpp" line="64"/>
+        <source>Period saves</source>
+        <translation>Ahorro del período</translation>
+    </message>
+    <message>
+        <location filename="../src/summarywindow.cpp" line="142"/>
+        <source>Warning: there are no expenses stored in the selected period</source>
+        <translation>Aviso: no hay gastos almacenados en el período seleccionado</translation>
+    </message>
+</context>
 </TS>
