@@ -10,6 +10,7 @@
 #include "expense.h"
 #include "concept.h"
 #include "monthdata.h"
+#include "summarydata.h"
 
 class DBManager : public QObject
 {
@@ -38,6 +39,9 @@ class DBManager : public QObject
         bool loadScheduled(QStandardItemModel *scheduled);
         bool updateScheduled(Expense *e);
 
+        bool getDataInterval(int &minYear, int &minMonth, int &maxYear, int &maxMonth);
+        bool load(SummaryData *summary);
+
  private:
         bool createTables();
         void initDB();
